@@ -4,7 +4,7 @@ import jsonschema
 
 class VerValues(object):
     MAJOR: int = 4
-    MINOR: int = 2
+    MINOR: int = 4
 
 
 class VerKeys(object):
@@ -26,6 +26,7 @@ class TaskKeys(object):
     Shell = "shell"
     ShellPath = "shell_path"
     Env = "env"
+    EnvInherit = "env_inherit"
     Cwd = "cwd"
     Base = "base"
     Hidden = "hidden"
@@ -53,6 +54,7 @@ class TaskKeys(object):
 
 
 class GlobalKeys(object):
+    Schema = "$schema"
     Include = "include"
     UseDfltInclude = "use_default_include"
     Version = "version"
@@ -84,6 +86,7 @@ _task_schema = {
                 "type": "string"
             }
         },
+        TaskKeys.EnvInherit: {"type": "boolean"},
         TaskKeys.StopOnError: {"type": "boolean"},
         TaskKeys.Hidden: {"type": "boolean"},
         TaskKeys.Abstract: {"type": "boolean"},
@@ -117,6 +120,10 @@ _task_schema = {
 _config_file_schema = {
     "type": "object",
     "properties": {
+        GlobalKeys.Schema: {
+            "type": "string",
+            "minLength": 1
+        },
         GlobalKeys.Version: {
             "type": "object",
             "properties": {
@@ -163,9 +170,20 @@ def validate_task_schema(name: str, data: dict) -> None:
         raise TaskException(f"Task schema validation error for '{name}': {e.message}")
 
 
-def dump_config_file_schema() -> None:
-    print_dict(_config_file_schema)
+class SchemaDumpOpts(object):
+    ALL = "all"
+    CONFIG = "config"
+    TASK = "task"
+
+    CHOICES = [ALL, CONFIG, TASK]
 
 
-def dump_task_schema() -> None:
-    print_dict(_task_schema)
+
+def dump_schema(dump_type: str) -> None:
+    if dump_type == SchemaDumpOpts.CONFIG:
+        print_dict(_config_file_schema)
+    elif dump_type == SchemaDumpOpts.TASK:
+        print_dict(_task_schema)
+    elif dump_type == SchemaDumpOpts.ALL:
+        _config_file_schema[GlobalKeys.Tasks] = _task_schema
+        print_dict(_config_file_schema)
